summaryrefslogtreecommitdiff
path: root/libpod/container.go
diff options
context:
space:
mode:
Diffstat (limited to 'libpod/container.go')
-rw-r--r--libpod/container.go6
1 files changed, 3 insertions, 3 deletions
diff --git a/libpod/container.go b/libpod/container.go
index 996f79ea4..4170ea443 100644
--- a/libpod/container.go
+++ b/libpod/container.go
@@ -93,7 +93,7 @@ type Container struct {
runningSpec *spec.Spec
- state *containerRuntimeInfo
+ state *containerState
// Locked indicates that a container has been locked as part of a
// Batch() operation
@@ -109,9 +109,9 @@ type Container struct {
// TODO enable pod support
// TODO Add readonly support
// containerRuntimeInfo contains the current state of the container
// It is stored on disk in a tmpfs and recreated on reboot
-type containerRuntimeInfo struct {
+type containerState struct {
// The current state of the running container
State ContainerStatus `json:"state"`
// The path to the JSON OCI runtime spec for this container
@@ -109,9 +109,9 @@ type Container struct {
// TODO enable pod support
// TODO Add readonly support
-// containerRuntimeInfo contains the current state of the container
+// containerState contains the current state of the container
// It is stored on disk in a tmpfs and recreated on reboot